@@ -2,6 +2,7 @@
 #include "mnModel.h"
 #include <wx/dir.h>
 #include <wx/regex.h>
+#include <wx/progdlg.h>
 #include <iconv.h>
 #include <ctype.h>
 
@@ -109,6 +110,52 @@ bool mnModel::matchWithToken(wxString* fileName, char* tokenList[])
 	return ans;
 }
 
+void mnModel::readAll(bool progBarFlag)
+{
+	int         fileCount = 0;
+	wxDir*      dir;
+	WikiData*   wikiData;
+    wxString*   fileName = new wxString();
+	char*       tokenList[MAX_TOKEN];
+	bool        cont;
+	wxProgressDialog* progBar = NULL;
+
+	memset(tokenList, 0, sizeof(char*)*MAX_TOKEN);
+	tokenList[0] = "";
+
+	dir = new wxDir(*wikiDataDir);
+    if ( !dir->IsOpened() )
+    {
+		MN_FATAL_ERROR(wxT("wxDir has faild\n"));
+        return ;
+    }
+   
+	/* count number of files */
+	if (progBarFlag) {
+		cont = dir->GetFirst(fileName, wxT("*.txt"), wxDIR_FILES);
+		while(cont){
+			fileCount++;
+			cont = dir->GetNext(fileName);
+		}
+		progBar = new wxProgressDialog(wxT("Searching Data"), (wxT("Now searching... ") + *wikiDataDir), fileCount);
+	}
+
+	fileCount = 0;
+    cont = dir->GetFirst(fileName, wxT("*.txt"), wxDIR_FILES);
+	while(cont){
+		fileCount++;
+		if (progBarFlag) progBar->Update(fileCount);
+		matchWithToken(fileName, tokenList); /* match with token list, but never match, just read. */
+        cont = dir->GetNext(fileName);
+	}
+
+	if (progBarFlag) {
+		delete progBar;
+	}
+	delete dir;
+	delete fileName;
+}
+
 WikiList* mnModel::search(const char* searchStr)
 {
 	int         i;
